==> helpdesk.selectransportation.com_BCK%2009.22.2025.zip: helpdesk.selectransportation.com/db_connection.php <==
<?php
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}


define('DB_NAME', 'PAN');
define('DB_USER', 'selectran');
define('DB_PASS', 'Bornwild110!');
define('DB_HOST', 'localhost');

// global $conn;
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);

if(!$conn)
{
    die('Could not connect to database: ' . mysqli_error($conn));
}
else{
   // echo "Connected Successfully!";
}



$db_select = mysqli_select_db($conn, DB_NAME);

if(!$db_select)
{
    die('Can\'t use ' . DB_NAME . ': ' . mysqli_error($conn));
}



$secretkey = 'waSenge^p2s5v8y/B?E(H+KbPeShVmYq3t6w9z$C&F)J@NcQfTjWnZr4u7x!A%D*G-KaPdSgUkXp2s5v8y/B?E(H+MbQeThWmYq3t6w9z$C&';

// function encryptthis($data, $secretkey) {
// $encryption_key = base64_decode($secretkey);
// $iv = openssl_random_pseudo_bytes(openssl_cipher_iv_length('aes-256-cbc'));
// $encrypted = openssl_encrypt($data, 'aes-256-cbc', $encryption_key, 0, $iv);
// return base64_encode($encrypted . '::' . $iv);
// }
//
// function decryptthis($data, $secretkey) {
// $encryption_key = base64_decode($secretkey);
// list($encrypted_data, $iv) = array_pad(explode('::', base64_decode($data), 2),2,null);
// return openssl_decrypt($encrypted_data, 'aes-256-cbc', $encryption_key, 0, $iv);
// }

if (!function_exists('encryptthis')) {
  function encryptthis($data, $secretkey) {
  $encryption_key = base64_decode($secretkey);
  $iv = openssl_random_pseudo_bytes(openssl_cipher_iv_length('aes-256-cbc'));
  $encrypted = openssl_encrypt($data, 'aes-256-cbc', $encryption_key, 0, $iv);
  return base64_encode($encrypted . '::' . $iv);
  }
}

if (!function_exists('decryptthis')) {
  function decryptthis($data, $secretkey) {
  $encryption_key = base64_decode($secretkey);
  list($encrypted_data, $iv) = array_pad(explode('::', base64_decode($data), 2),2,null);
  return openssl_decrypt($encrypted_data, 'aes-256-cbc', $encryption_key, 0, $iv);
  }
}


 ?>

==> helpdesk.selectransportation.com_BCK%2010.14.2025.zip: helpdesk.selectransportation.com/db_connection.php <==
<?php
if (session_status() == PHP_SESSION_NONE) {
    session_start();
}


defined('DB_NAME') or define('DB_NAME', 'PAN');
defined('DB_USER') or define('DB_USER', 'selectran');
defined('DB_PASS') or define('DB_PASS', 'Bornwild110!');
defined('DB_HOST') or define('DB_HOST', 'localhost');

// global $conn;
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);

if(!$conn)
{
    die('Could not connect to database: ' . mysqli_error($conn));
}
else{
   // echo "Connected Successfully!";
}



$db_select = mysqli_select_db($conn, DB_NAME);

if(!$db_select)
{
    die('Can\'t use ' . DB_NAME . ': ' . mysqli_error($conn));
}



$secretkey = 'waSenge^p2s5v8y/B?E(H+KbPeShVmYq3t6w9z$C&F)J@NcQfTjWnZr4u7x!A%D*G-KaPdSgUkXp2s5v8y/B?E(H+MbQeThWmYq3t6w9z$C&';
// $secretkey = 'w+ALdl5P+5+Fh3lXrKffURqtBoQygdUOgDNlsR8EfI0=';


// function encryptthis($data, $secretkey) {
// $encryption_key = base64_decode($secretkey);
// $iv = openssl_random_pseudo_bytes(openssl_cipher_iv_length('aes-256-cbc'));
// $encrypted = openssl_encrypt($data, 'aes-256-cbc', $encryption_key, 0, $iv);
// return base64_encode($encrypted . '::' . $iv);
// }
//
// function decryptthis($data, $secretkey) {
// $encryption_key = base64_decode($secretkey);
// list($encrypted_data, $iv) = array_pad(explode('::', base64_decode($data), 2),2,null);
// return openssl_decrypt($encrypted_data, 'aes-256-cbc', $encryption_key, 0, $iv);
// }

if (!function_exists('encryptthis')) {
  function encryptthis($data, $secretkey) {
  $encryption_key = base64_decode($secretkey);
  $iv = openssl_random_pseudo_bytes(openssl_cipher_iv_length('aes-256-cbc'));
  $encrypted = openssl_encrypt($data, 'aes-256-cbc', $encryption_key, 0, $iv);
  return base64_encode($encrypted . '::' . $iv);
  }
}

if (!function_exists('decryptthis')) {
  function decryptthis($data, $secretkey) {
  $encryption_key = base64_decode($secretkey);
  list($encrypted_data, $iv) = array_pad(explode('::', base64_decode($data), 2),2,null);
  return openssl_decrypt($encrypted_data, 'aes-256-cbc', $encryption_key, 0, $iv);
  }
}


 ?>
